@@ -2,7 +2,7 @@
 #'
 #' Wrappers for working with the clipboard
 #'
-#' @details As these functions rely on [utils::readClipboard()] and
+#' @details As these functions rely on [clipr::read_clip()] and
 #' [utils::writeClipboard()] they are only available for Windows 10. For copying
 #' and pasting floats, there may be some rounding that can occur.
 #'
@@ -51,16 +51,19 @@ write_clipboard <- function(x, ...) {
 #' @export
 #' @rdname clipboard
 write_clipboard.default <- function(x, ...) {
-  utils::writeClipboard(str = as.character(x), format = 1L)
+  x <- as.character(x)
+  clipr::write_clip(x, allow_non_interactive = TRUE)
 }
 
 #' @export
 #' @rdname clipboard
 #' @inheritParams utils::write.table
-write_clipboard.data.frame <- function(x, sep = "\t", row.names = FALSE, ...) { # nolint: object_name_linter, line_length_linter.
-  utils::write.table(
-    x,
-    file = "clipboard-128",
+# nolint next: object_name_linter.
+write_clipboard.data.frame <- function(x, sep = "\t", row.names = FALSE, ...) {
+  fuj::require_namespace("clipr")
+  clipr::write_clip(
+    content = x,
+    allow_non_interactive = TRUE,
     sep = sep,
     row.names = row.names,
     ...
@@ -82,37 +85,75 @@ write_clipboard.list <- function(x, sep = "\t", ...) {
 
 #' @export
 #' @rdname clipboard
-read_clipboard <- function(method = c("default", "data.frame", "tibble"), ...) {
-  if (!is_windows()) {
-    stop(cond_read_clipboard_windows())
-  }
-
+read_clipboard <- function(method = read_clipboard_methods(), ...) {
+  fuj::require_namespace("clipr")
   switch(
     match_param(method),
-
-    default = {
-      x <- utils::readClipboard(format = 1L, raw = FALSE)
-      type_convert2(x)
-    },
-
-    # Specifications I prefer -- mostly copying from Excel
-    data.frame = {
-      tab <- do_read_table_clipboard(...)
-
-      for (i in seq_along(tab)) {
-        tab[[i]] <- type_convert2(tab[[i]])
-      }
-
-      tab
-    },
-
-    tibble = {
-      require_namespace("tibble")
-      tibble::as_tibble(read_clipboard("data.frame", ...))
+    default = type_convert2(clipr_read_clip(TRUE)),
+    tibble = ,
+    excel = ,
+    calc = ,
+    # default are specifications for excel/calc
+    data.frame = type_convert2(do_read_table_clipboard(...)),
+    csv = read_clipboard("data.frame", sep = ",", ...),
+    csv2 = read_clipboard("data.frame", sep = ";", ...),
+    bsv = ,
+    psv = read_clipboard("data.frame", sep = "|", ...),
+    tsv = read_clipboard("data.frame", sep = "\t", ...),
+    md = {
+      fuj::require_namespace("readMDTable")
+      temp <- fs::file_temp()
+      on.exit(fs::file_delete(temp), add = TRUE)
+      writeLines(read_clipboard(), temp)
+      params <- list0(...)
+      params$file <- temp
+      params$show_col_types <- params$show_col_types %||% FALSE
+      params$col_types <- params$col_types %||% list(.default = "character")
+      type_convert2(do.call(readMDTable::read_md_table, params))
     }
   )
 }
 
+clipr_read_clip <- function(...) {
+  res <- withCallingHandlers(
+    clipr::read_clip(...),
+    simpleWarning = function(e) {
+      if (grepl(
+        "System clipboard contained no readable text",
+        conditionMessage(e),
+        fixed = TRUE
+      )) {
+        tryInvokeRestart("muffleWarning")
+      }
+    }
+  )
+
+  if (is_windows() && (isNA(res) || (length(res) == 1L && !nzchar(res)))) {
+    NULL
+  } else {
+    res
+  }
+}
+
+#' @export
+#' @rdname clipboard
+read_clipboard_methods <- function() {
+  c(
+    "default",
+    "data.frame",
+    "tibble",
+    "excel",
+    "calc",
+    "csv",
+    "csv2",
+    "bsv",
+    "psv",
+    "tsv",
+    "md",
+    NULL
+  )
+}
+
 # helpers -----------------------------------------------------------------
 
 #' Read table from clipboard
@@ -121,26 +162,30 @@ read_clipboard <- function(method = c("default", "data.frame", "tibble"), ...) {
 #'
 #' @inheritParams utils::read.table
 #' @noRd
-# nolint start: object_name_linter.
 do_read_table_clipboard <- function(
     header           = TRUE,
     # Copying form Excel produces tab separations
     sep              = "\t",
+    # nolint next: object_name_linter.
     row.names        = NULL,
     # Excel formula for NA produces #N/A -- sometimes people use N/A...
+    # nolint next: object_name_linter.
     na.strings       = c("", "NA", "N/A", "#N/A"),
+    # nolint next: object_name_linter.
     check.names      = FALSE,
+    # nolint next: object_name_linter.
     stringsAsFactors = FALSE,
     encoding         = "UTF-8",
     # occasionally "#' is used as a column name -- may cause issues
+    # nolint next: object_name_linter.
     comment.char     = "",
+    # nolint next: object_name_linter.
     blank.lines.skip = FALSE,
     fill             = TRUE,
     ...
-    # nolint end: object_name_linter.
 ) {
-  utils::read.table(
-    file             = "clipboard-128",
+  res <- utils::read.table(
+    file = textConnection(clipr_read_clip(TRUE)),
     header           = header,
     sep              = sep,
     row.names        = row.names,
@@ -153,14 +198,16 @@ do_read_table_clipboard <- function(
     fill             = fill,
     ...
   )
+
+  if (package_available("tibble")) {
+    tibble::as_tibble(res)
+  } else {
+    res
+  }
 }
 
 clear_clipboard <- function() {
-  if (!is_windows()) {
-    stop("`mark::write_clipboard()` is only valid for Windows", call. = FALSE)
-  }
-
-  utils::writeClipboard("", format = 1L)
+  clipr::clear_clip(allow_non_interactive = TRUE)
 }
 
 # nocov end
@@ -168,6 +215,11 @@ clear_clipboard <- function() {
 # coverage ----------------------------------------------------------------
 
 type_convert2 <- function(x) {
+  if (is.data.frame(x)) {
+    x[] <- lapply(x, type_convert2)
+    return(x)
+  }
+
   if (!is.character(x)) {
     return(x)
   }
@@ -195,7 +247,6 @@ type_convert2 <- function(x) {
 
     dates <- as_date_strptime(x0)
 
-    # if (isTRUE(all.equal(as.character(dates), x0))) {
     if (!anyNA(dates)) {
       return(as_date_strptime(x))
     }
@@ -203,12 +254,3 @@ type_convert2 <- function(x) {
 
   res
 }
-
-# conditions --------------------------------------------------------------
-
-cond_read_clipboard_windows <- function() {
-  new_condition(
-    "`mark::read_clipboard()` is only valid for Windows",
-    "read_clipboard_windows"
-  )
-}
