@@ -1,5 +1,5 @@
 .onAttach <- function(libname, pkgname) {
-  options(op.mark[names(op.mark) %out% names(options())])
+  options(op.mark[!names(op.mark) %in% names(options())])
 }
 
 .onDetach <- function(libpath) {
